diff --git a/CMakeLists.txt b/CMakeLists.txt
index 08965ac..ff9970e 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -2,7 +2,7 @@ cmake_minimum_required(VERSION 3.5)
 cmake_policy(SET CMP0048 NEW)
 project (Bloaty VERSION 1.0)
 project (Bloaty VERSION 1.1)
-set(CMAKE_CXX_STANDARD 11)
+set(CMAKE_CXX_STANDARD 17)
 
 # Options we define for users.
 option(BLOATY_ENABLE_ASAN "Enable address sanitizer." OFF)
@@ -36,6 +36,8 @@ else(${PKG_CONFIG_FOUND})
 endif(${PKG_CONFIG_FOUND})
 endif(UNIX)
 
+find_package(absl)
+
 # Set default build type.
 if(NOT CMAKE_BUILD_TYPE)
   message(STATUS "Setting build type to 'RelWithDebInfo' as none was specified.")
@@ -89,11 +91,10 @@ endif(UNIX)
 
 include_directories(.)
 include_directories(src)
-include_directories(third_party/abseil-cpp)
 include_directories("${CMAKE_CURRENT_BINARY_DIR}/src")
 
 # Baseline build flags.
-set(CMAKE_CXX_FLAGS "-std=c++11 -W -Wall -Wno-sign-compare")
+set(CMAKE_CXX_FLAGS "-std=c++17 -W -Wall -Wno-sign-compare")
 set(CMAKE_CXX_FLAGS_DEBUG "-g1")
 set(CMAKE_CXX_FLAGS_RELEASE "-O2")
 set(CMAKE_CXX_FLAGS_RELWITHDEBINFO "-O2 -g1")
@@ -159,28 +160,12 @@ add_library(libbloaty
     src/macho.cc
     src/range_map.cc
     src/webassembly.cc
-    # Until Abseil has a proper CMake build system
-    third_party/abseil-cpp/absl/base/internal/raw_logging.cc # Grrrr...
-    third_party/abseil-cpp/absl/base/internal/throw_delegate.cc
-    third_party/abseil-cpp/absl/numeric/int128.cc
-    third_party/abseil-cpp/absl/strings/ascii.cc
-    third_party/abseil-cpp/absl/strings/charconv.cc
-    third_party/abseil-cpp/absl/strings/escaping.cc
-    third_party/abseil-cpp/absl/strings/internal/charconv_bigint.cc
-    third_party/abseil-cpp/absl/strings/internal/charconv_parse.cc
-    third_party/abseil-cpp/absl/strings/internal/memutil.cc
-    third_party/abseil-cpp/absl/strings/internal/utf8.cc
-    third_party/abseil-cpp/absl/strings/match.cc
-    third_party/abseil-cpp/absl/strings/numbers.cc
-    third_party/abseil-cpp/absl/strings/str_cat.cc
-    third_party/abseil-cpp/absl/strings/string_view.cc
-    third_party/abseil-cpp/absl/strings/str_split.cc
-    third_party/abseil-cpp/absl/strings/substitute.cc
-    third_party/abseil-cpp/absl/types/bad_optional_access.cc
     # One source file, no special build system needed.
     third_party/demumble/third_party/libcxxabi/cxa_demangle.cpp
     )
 
+set(LIBBLOATY_LIBS ${LIBBLOATY_LIBS} absl::strings absl::optional)
+
 if(UNIX)
   set(LIBBLOATY_LIBS libbloaty)
   if(${PROTOBUF_FOUND})
diff --git a/src/bloaty.cc b/src/bloaty.cc
index 017a25c..d132646 100644
--- a/src/bloaty.cc
+++ b/src/bloaty.cc
@@ -38,6 +38,8 @@
 #include <sys/wait.h>
 #include <unistd.h>
 
+#include <absl/strings/escaping.h>
+#include <absl/strings/str_cat.h>
 #include "absl/memory/memory.h"
 #include "absl/strings/numbers.h"
 #include "absl/strings/string_view.h"
diff --git a/src/range_map.h b/src/range_map.h
index 9faa9e8..8842928 100644
--- a/src/range_map.h
+++ b/src/range_map.h
@@ -32,6 +32,7 @@
 #include <assert.h>
 #include <stdint.h>
 
+#include <stdexcept>
 #include <exception>
 #include <map>
 #include <vector>
